@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-04-16 14:38:22
-:LastEditTime: 2020-11-06 11:12:03
+:LastEditTime: 2021-11-05 11:34:05
 :LastEditors: ChenXiaolei
 :Description: 
 """
@@ -22,4 +22,6 @@ from .excel import *
 from .csv import *
 from .qr_code import *
 from .sign import *
-from .work_wechat import *
\ No newline at end of file
+from .work_wechat import *
+from .os import *
+from .ip import *
\ No newline at end of file
