@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2022-04-08 16:19:35
+:LastEditTime: 2023-01-17 16:41:36
 :LastEditors: ChenXiaolei
 :Description: 数据库基础操作类
 """
@@ -98,13 +98,13 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY "+group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
         if limit:
-            limit = " LIMIT "+str(limit)
+            limit = f" LIMIT {str(limit)}"
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         list_row = self.db.fetch_all_rows(sql, params)
         return self.__row_entity_list(list_row)
@@ -116,7 +116,8 @@ class BaseModel:
                       where='',
                       group_by='',
                       order_by='',
-                      params=None):
+                      params=None,
+                      page_count_mode='total'):
         """
         :Description: 分页获取数据
         :param field: 查询字段 
@@ -126,32 +127,43 @@ class BaseModel:
         :param group_by: GROUP BY 语句
         :param order_by:  ORDER BY 语句
         :param params: 参数化查询参数
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
         :return: 模型实体列表
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY " + group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
+
+        if page_count_mode == "next":
+            page_size = page_size+1
 
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {str(int(page_index) * int(page_size))},{str(page_size)};"
         list_row = self.db.fetch_all_rows(sql, params)
 
-        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+        if page_count_mode == "total":
+            sql = f"SELECT COUNT(`{self.primary_key_field}`) AS count FROM {self.table_name}{where}{group_by}"
+            if group_by:
+                sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
 
-        if group_by:
-            sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
+            row = self.db.fetch_one_row(sql, params)
 
-        row = self.db.fetch_one_row(sql, params)
+            if row and 'count' in row and int(row['count']) > 0:
+                row_count = int(row["count"])
+            else:
+                row_count = 0
 
-        if row and 'count' in row and int(row['count']) > 0:
-            row_count = int(row["count"])
+            return self.__row_entity_list(list_row), row_count
+        elif page_count_mode == "next":
+            is_next_page = len(list_row) == page_size
+            if list_row and len(list_row)>0:
+                list_row = list_row[:page_size-1]
+            return self.__row_entity_list(list_row), is_next_page
         else:
-            row_count = 0
-
-        return self.__row_entity_list(list_row), row_count
+            return self.__row_entity_list(list_row)
 
     def get_entity(self, where='', group_by='', order_by='',  params=None):
         """
@@ -164,11 +176,11 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY "+group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by} LIMIT 1;"
         list_row = self.db.fetch_one_row(sql, params)
         return self.__row_entity(list_row)
@@ -195,21 +207,19 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY "+group_by
+            group_by = f" GROUP BY {group_by}"
         if not field:
             field = self.primary_key_field
-        sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by}"
+        sql = f"SELECT COUNT(`{field}`) AS count FROM {self.table_name}{where}{group_by}"
 
         if group_by:
             sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
 
         list_row = self.db.fetch_one_row(sql, params)
 
-        if list_row and 'count' in list_row:
-            return list_row['count']
-        return 0
+        return list_row['count'] if list_row and 'count' in list_row else 0
 
     def del_entity(self, where, params=None, limit=""):
         """
@@ -219,25 +229,21 @@ class BaseModel:
         :return: 
         :last_editors: ChenXiaolei
         """
-        if where:
-            where = "WHERE " + where
-            if limit and limit.lower().find("limit")<0:
-                limit = f"LIMIT {limit}"
+        if not where:
+            return
+        where = f"WHERE {where}"
+        if limit and limit.lower().find("limit") < 0:
+            limit = f"LIMIT {limit}"
 
-            sql = f"DELETE FROM {self.table_name} {where} {limit}"
+        sql = f"DELETE FROM {self.table_name} {where} {limit}"
 
-            if self.is_transaction():
-                transaction_item = {}
-                transaction_item["sql"] = sql
-                transaction_item["params"] = params
-                self.db_transaction.transaction_list.append(transaction_item)
-                return True
-            else:
-                list_row = self.db.delete(sql, params)
-                if list_row is not None and list_row > 0:
-                    return True
-                else:
-                    return False
+        if self.is_transaction():
+            transaction_item = {"sql": sql, "params": params}
+            self.db_transaction.transaction_list.append(transaction_item)
+            return True
+        else:
+            list_row = self.db.delete(sql, params)
+            return list_row is not None and list_row > 0
 
     def add_entity(self, model, ignore=False, return_increment_primary=True):
         """
@@ -256,22 +262,18 @@ class BaseModel:
             param_value = str(getattr(model, field_str))
             if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
                 continue
-            insert_field_str += str(field_str + ",")
+            insert_field_str += str(f"`{field_str}`,")
             insert_value_str += "%s,"
             param.append(param_value)
         insert_field_str = insert_field_str.rstrip(',')
         insert_value_str = insert_value_str.rstrip(',')
         sql = f"INSERT{' IGNORE' if ignore else ''} INTO {self.table_name}({insert_field_str}) VALUE({insert_value_str});"
-        if self.is_transaction():
-            transaction_item = {}
-            transaction_item["sql"] = sql
-            transaction_item["params"] = tuple(param)
-            self.db_transaction.transaction_list.append(transaction_item)
-            return True
-        else:
-            list_row = self.db.insert(sql, tuple(
-                param), return_increment_primary)
-            return list_row
+        if not self.is_transaction():
+            return self.db.insert(sql, tuple(param), return_increment_primary)
+
+        transaction_item = {"sql": sql, "params": tuple(param)}
+        self.db_transaction.transaction_list.append(transaction_item)
+        return True
 
     def add_list(self, model_list, ignore=False, transaction=False):
         """
@@ -296,16 +298,14 @@ class BaseModel:
                 param_value = str(getattr(model, field_str))
                 if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
                     continue
-                insert_field_str += str(field_str + ",")
+                insert_field_str += str(f"`{field_str}`,")
                 insert_value_str += "%s,"
                 param.append(param_value)
             insert_field_str = insert_field_str.rstrip(',')
             insert_value_str = insert_value_str.rstrip(',')
             sql = f"INSERT{' IGNORE' if ignore else ''} INTO {self.table_name}({insert_field_str}) VALUE({insert_value_str});"
 
-            sql_item = {}
-            sql_item["sql"] = sql
-            sql_item["params"] = tuple(param)
+            sql_item = {"sql": sql, "params": tuple(param)}
             if self.is_transaction():
                 self.db_transaction.transaction_list.append(sql_item)
             elif transaction:
@@ -335,7 +335,7 @@ class BaseModel:
         for field_str in field_list:
             if str(field_str).lower() == self.primary_key_field.lower():
                 continue
-            insert_field_str += str(field_str + ",")
+            insert_field_str += str(f"`{field_str}`,")
 
         insert_field_str = insert_field_str.rstrip(',')
 
@@ -385,24 +385,20 @@ class BaseModel:
             param_value = str(getattr(model, field_str))
             if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
                 continue
-            insert_field_str += str(field_str + ",")
+            insert_field_str += str(f"`{field_str}`,")
             insert_value_str += "%s,"
             param.append(param_value)
         if params:
-            param = param+params
+            param += params
         insert_field_str = insert_field_str.rstrip(',')
         insert_value_str = insert_value_str.rstrip(',')
         sql = f"INSERT INTO {self.table_name}({insert_field_str}) VALUE({insert_value_str}) ON DUPLICATE KEY UPDATE {update_sql};"
-        if self.is_transaction():
-            transaction_item = {}
-            transaction_item["sql"] = sql
-            transaction_item["params"] = tuple(param)
-            self.db_transaction.transaction_list.append(transaction_item)
-            return True
-        else:
-            list_row = self.db.insert(sql, tuple(
-                param), return_increment_primary)
-            return list_row
+        if not self.is_transaction():
+            return self.db.insert(sql, tuple(param), return_increment_primary)
+
+        transaction_item = {"sql": sql, "params": tuple(param)}
+        self.db_transaction.transaction_list.append(transaction_item)
+        return True
 
     def add_update_whole_entity(self, model, exclude_duplicate_key_field_list=None, return_increment_primary=True):
         """
@@ -425,12 +421,12 @@ class BaseModel:
             param_value = str(getattr(model, field_str))
             if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
                 continue
-            insert_field_str += str(field_str + ",")
+            insert_field_str += str(f"`{field_str}`,")
             insert_value_str += "%s,"
             param.append(param_value)
 
             if exclude_duplicate_key_field_list and field_str not in exclude_duplicate_key_field_list:
-                update_sql += f"{field}=%s,"
+                update_sql += f"{field_str}=%s,"
                 update_param.append(param_value)
 
         insert_field_str = insert_field_str.rstrip(',')
@@ -440,16 +436,12 @@ class BaseModel:
         param.extend(update_param)
 
         sql = f"INSERT INTO {self.table_name}({insert_field_str}) VALUE({insert_value_str}) ON DUPLICATE KEY UPDATE {update_sql};"
-        if self.is_transaction():
-            transaction_item = {}
-            transaction_item["sql"] = sql
-            transaction_item["params"] = tuple(param)
-            self.db_transaction.transaction_list.append(transaction_item)
-            return True
-        else:
-            list_row = self.db.insert(sql, tuple(
-                param), return_increment_primary)
-            return list_row
+        if not self.is_transaction():
+            return self.db.insert(sql, tuple(param), return_increment_primary)
+
+        transaction_item = {"sql": sql, "params": tuple(param)}
+        self.db_transaction.transaction_list.append(transaction_item)
+        return True
 
     def update_entity(self, model, field_list=None, exclude_field_list=None):
         """
@@ -527,10 +519,11 @@ class BaseModel:
 
         exclude_field = None
 
-        if exclude_field_list and type(exclude_field_list) == list:
-            exclude_field = exclude_field_list
-        elif exclude_field_list and type(exclude_field_list) == str:
-            exclude_field = exclude_field_list.split(",")
+        if exclude_field_list:
+            if type(exclude_field_list) == list:
+                exclude_field = exclude_field_list
+            elif type(exclude_field_list) == str:
+                exclude_field = exclude_field_list.split(",")
 
         if exclude_field:
             for exclude_field in exclude_field_list:
@@ -547,7 +540,7 @@ class BaseModel:
             for field_str in field_list:
                 if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
                     continue
-                update_field_str += str(field_str + "=%s,")
+                update_field_str += str(f"`{field_str}`=%s,")
                 if str(field_str).lower() == "edit_on":
                     now = datetime.datetime.now()
                     param.append(str(now.strftime("%Y-%m-%d %H:%M:%S")))
@@ -559,21 +552,14 @@ class BaseModel:
                 continue
             sql = f"UPDATE {self.table_name} SET {update_field_str} WHERE {self.primary_key_field}=%s;"
             if self.is_transaction():
-                transaction_item = {}
-                transaction_item["sql"] = sql
-                transaction_item["params"] = tuple(param)
+                transaction_item = {"sql": sql, "params": tuple(param)}
                 self.db_transaction.transaction_list.append(transaction_item)
             elif transaction:
-                transaction_item = {}
-                transaction_item["sql"] = sql
-                transaction_item["params"] = tuple(param)
+                transaction_item = {"sql": sql, "params": tuple(param)}
                 sql_list.append(transaction_item)
             else:
                 self.db.update(sql, tuple(param))
-        if transaction and not self.is_transaction():
-            if not self.transaction_execute(sql_list):
-                return False
-        return True
+        return bool(not transaction or self.is_transaction() or self.transaction_execute(sql_list))
 
     def update_table(self, update_sql, where, params=None, limit=""):
         """
@@ -585,9 +571,9 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
 
-        if limit and limit.lower().find("limit")<0:
+        if limit and limit.lower().find("limit") < 0:
             limit = f"LIMIT {limit}"
 
         sql = f"UPDATE {self.table_name} SET {update_sql}{where} {limit};"
@@ -618,16 +604,15 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY "+group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
         if limit:
-            limit = " LIMIT "+str(limit)
+            limit = f" LIMIT {str(limit)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
-        one_row = self.db.fetch_one_row(sql, params)
-        return one_row  # self.__row_entity(list_row)
+        return self.db.fetch_one_row(sql, params)
 
     def get_dict_by_id(self, primary_key_id, field="*"):
         """
@@ -638,8 +623,7 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         sql = f"SELECT {field} FROM {self.table_name} WHERE {self.primary_key_field}=%s;"
-        one_row = self.db.fetch_one_row(sql, primary_key_id)
-        return one_row
+        return self.db.fetch_one_row(sql, primary_key_id)
 
     def get_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None):
         """
@@ -654,13 +638,13 @@ class BaseModel:
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY "+group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
         if limit:
-            limit = " LIMIT "+str(limit)
+            limit = f" LIMIT {str(limit)}"
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         list_row = self.db.fetch_all_rows(sql, params)
 
@@ -676,7 +660,8 @@ class BaseModel:
                            where='',
                            group_by='',
                            order_by='',
-                           params=None):
+                           params=None,
+                           page_count_mode='total'):
         """
         :Description: 获取分页字典数据
         :param field: 查询字段 
@@ -686,15 +671,19 @@ class BaseModel:
         :param group_by: GROUP BY 语句
         :param order_by:  ORDER BY 语句
         :param params: 参数化查询参数
+        :param page_count_mode: 分页计数模式 total-计算总数(默认) next-计算是否有下一页(bool) none-不计算
         :return: 数据字典数组
         :last_editors: ChenXiaolei
         """
         if where and where.strip() != '':
-            where = " WHERE " + where
+            where = f" WHERE {where}"
         if group_by and group_by.strip() != '':
-            group_by = " GROUP BY " + group_by
+            group_by = f" GROUP BY {group_by}"
         if order_by and order_by.strip() != '':
-            order_by = " ORDER BY " + order_by
+            order_by = f" ORDER BY {order_by}"
+
+        if page_count_mode == "next":
+            page_size = page_size+1
 
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"
         list_row = self.db.fetch_all_rows(sql, params)
@@ -702,18 +691,26 @@ class BaseModel:
         if not list_row:
             list_row = []
 
-        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+        if page_count_mode == "total":
+            sql = f"SELECT COUNT(`{self.primary_key_field}`) AS count FROM {self.table_name}{where}{group_by}"
 
-        if group_by:
-            sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table"
-        row = self.db.fetch_one_row(sql, params)
+            if group_by:
+                sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table"
+            row = self.db.fetch_one_row(sql, params)
 
-        if row and 'count' in row and int(row['count']) > 0:
-            row_count = int(row["count"])
+            if row and 'count' in row and int(row['count']) > 0:
+                row_count = int(row["count"])
+            else:
+                row_count = 0
+
+            return list_row, row_count
+        elif page_count_mode == "next":
+            is_next_page = len(list_row) == page_size
+            if list_row and len(list_row)>0:
+                list_row = list_row[:page_size-1]
+            return list_row, is_next_page
         else:
-            row_count = 0
-
-        return list_row, row_count
+            return list_row
 
     def transaction_execute(self, sql_list):
         """
@@ -756,7 +753,7 @@ class BaseModel:
                 param_value = str(getattr(model, field_str))
                 if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
                     continue
-                insert_field_str += str(field_str + ",")
+                insert_field_str += str(f"`{field_str}`,")
                 insert_value_str += f"'{param_value}',"
             insert_field_str = insert_field_str.rstrip(',')
             insert_value_str = insert_value_str.rstrip(',')
@@ -787,9 +784,9 @@ class BaseModel:
                 if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
                     continue
                 if str(field_str).lower() == "edit_on":
-                    update_field_str += f"{str(field_str)}='{TimeHelper.get_now_format_time()}',"
+                    update_field_str += f"`{str(field_str)}`='{TimeHelper.get_now_format_time()}',"
                 else:
-                    update_field_str += f"{str(field_str)}='{str(getattr(model, field_str))}',"
+                    update_field_str += f"`{str(field_str)}`='{str(getattr(model, field_str))}',"
 
             update_field_str = update_field_str.rstrip(',')
             build_sql = build_sql + \
@@ -813,7 +810,7 @@ class BaseModel:
             insert_field_str = ""
             insert_value_str = ""
             for field_str in field_list:
-                insert_field_str += str(field_str + ",")
+                insert_field_str += str(f"`{field_str}`,")
                 insert_value_str += f"'{str(getattr(model, field_str))}',"
             insert_field_str = insert_field_str.rstrip(',')
             insert_value_str = insert_value_str.rstrip(',')
