@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-05-19 10:33:52
-:LastEditTime: 2022-01-18 19:24:56
+:LastEditTime: 2022-05-24 20:28:56
 :LastEditors: ChenXiaolei
 :Description: ufile传输
 """
@@ -1380,8 +1380,8 @@ class S3Helper():
         :last_editors: ChenXiaolei
         """
         try:
-            self.s3_client.upload_file(
-                Bucket=bucket_name, Key=object_name, Filename=source_file_object)
+            from io import BytesIO
+            self.s3_client.upload_fileobj(BytesIO(source_file_object),bucket_name,object_name)
 
             return True
         except:
