@@ -67,7 +67,8 @@ class MySQLHelper(object):
             if hasattr(self, "context") and self.context:
                 # 如果上下文不存在logging_link_sql方法,打印上下文信息
                 if not hasattr(self.context, "logging_link_sql"):
-                    print(f"MySQLHelper context has no attribute 'logging_link_sql' context:{self.context.__dict__}")
+                    print(
+                        f"MySQLHelper context has no attribute 'logging_link_sql' context:{self.context.__dict__}")
                     return
                 self.context.logging_link_sql(log_msg)
             elif hasattr(self, "_log_sql") and self._log_sql:
@@ -183,6 +184,7 @@ class MySQLHelper(object):
 
         try:
             self.connection()
+            self._conn.begin()
             self._cur = self._conn.cursor(pymysql.cursors.DictCursor)
 
             for item in sql_list:
@@ -210,9 +212,12 @@ class MySQLHelper(object):
             self._conn.commit()  # 事务提交
             self._cur.close()
             self._conn.close()
+
+        self._add_sql_log("transaction commit")
+
         if return_detail_tuple:
             return (True, "")
-        self._add_sql_log("transaction commit")
+
         return True
 
     def fetch_all_rows(self, sql, params=None):
