@@ -9,6 +9,7 @@
 
 import time
 import datetime
+import calendar
 from dateutil.relativedelta import relativedelta
 
 
@@ -103,12 +104,15 @@ class TimeHelper:
         :return: datetime
         :last_editors: ChenXiaolei
         """
-        if timestamp:
-            time_tuple = time.localtime(timestamp)
-            result = time.strftime(format, time_tuple)
-            return result
-        else:
-            return time.strftime(format)
+        if not timestamp:
+            return datetime.datetime.now().strftime(format)
+
+        if len(str(timestamp))==13:
+            # 毫秒处理
+            timestamp = timestamp / 1000.0
+
+        return datetime.datetime.fromtimestamp(timestamp).strftime(format)
+
 
     @classmethod
     def timestamp_to_datetime(self, timestamp=time.time()):
@@ -524,8 +528,7 @@ class TimeHelper:
         :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
-        return datetime.datetime(now_datetime.year, now_datetime.month + 1,
-                                 1) - datetime.timedelta(days=1)
+        return datetime.datetime(now_datetime.year, now_datetime.month, calendar.monthrange(now_datetime.year, now_datetime.month)[1])
 
     @classmethod
     def is_this_month(self, date, format='%Y-%m-%d %H:%M:%S'):
