@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2022-04-07 14:20:59
+:LastEditTime: 2022-11-23 15:17:46
 :LastEditors: ChenXiaolei
 :Description: Handler基础类
 """
@@ -29,6 +29,7 @@ from seven_framework import *
 class BaseHandler(tornado.web.RequestHandler):
     # 最大线程池数量
     THREAD_POOL_COUNT = config.get_value("thread_pool_count", 5000)
+    IS_CHECK_XSRF = config.get_value("is_check_xsrf",False)
     """
     :Description: 基础handler
     :last_editors: ChenXiaolei
@@ -71,6 +72,10 @@ class BaseHandler(tornado.web.RequestHandler):
         await asyncio.get_event_loop().run_in_executor(self.executor,
                                                        self.options_async, *args)
 
+    async def patch(self, *args, **kwargs):
+        await asyncio.get_event_loop().run_in_executor(self.executor,
+                                                       self.patch_async, *args)
+
     def prepare(self, *args, **argkw):
         """
         :Description: 置于任何请求方法前被调用(请勿重写此函数,可重写prepare_ext)
@@ -188,6 +193,9 @@ class BaseHandler(tornado.web.RequestHandler):
                     result |= ord(x) ^ ord(y)
             return result == 0
 
+        if not self.IS_CHECK_XSRF:
+            return
+            
         if '/api/' in self.request.uri:
             return
         else:
@@ -564,6 +572,7 @@ def filter_check_sign(sign_key, sign_lower=False, reverse=False, is_sign_key=Fal
     """
     :description: http请求签名验证装饰器
     :param sign_key: 参与签名的私钥
+    :param sign_lower: 返回签名是否小写(默认大写)
     :param reverse: 是否反排序 False:升序 True:降序
     :param is_sign_key: 参数名是否参与签名(默认False不参与)
     :param expired_seconds: 接口timestamp过期时间(秒)
